@@ -1,10 +1,10 @@
-INSERT INTO version (table_name, table_version) values ('dialog','10');
+INSERT INTO version (table_name, table_version) values ('dialog','12');
 CREATE TABLE dialog (
     dlg_id BIGINT PRIMARY KEY NOT NULL,
     callid VARCHAR(255) NOT NULL,
-    from_uri VARCHAR(128) NOT NULL,
+    from_uri VARCHAR(255) NOT NULL,
     from_tag VARCHAR(64) NOT NULL,
-    to_uri VARCHAR(128) NOT NULL,
+    to_uri VARCHAR(255) NOT NULL,
     to_tag VARCHAR(64) NOT NULL,
     mangled_from_uri VARCHAR(64) DEFAULT NULL,
     mangled_to_uri VARCHAR(64) DEFAULT NULL,
@@ -14,8 +14,8 @@ CREATE TABLE dialog (
     callee_ping_cseq INTEGER NOT NULL,
     caller_route_set TEXT,
     callee_route_set TEXT,
-    caller_contact VARCHAR(128),
-    callee_contact VARCHAR(128),
+    caller_contact VARCHAR(255),
+    callee_contact VARCHAR(255),
     caller_sock VARCHAR(64) NOT NULL,
     callee_sock VARCHAR(64) NOT NULL,
     state INTEGER NOT NULL,
@@ -23,8 +23,11 @@ CREATE TABLE dialog (
     timeout INTEGER NOT NULL,
     vars BYTEA DEFAULT NULL,
     profiles TEXT DEFAULT NULL,
-    script_flags INTEGER DEFAULT 0 NOT NULL,
+    script_flags VARCHAR(255) DEFAULT NULL,
     module_flags INTEGER DEFAULT 0 NOT NULL,
-    flags INTEGER DEFAULT 0 NOT NULL
+    flags INTEGER DEFAULT 0 NOT NULL,
+    rt_on_answer VARCHAR(64) DEFAULT NULL,
+    rt_on_timeout VARCHAR(64) DEFAULT NULL,
+    rt_on_hangup VARCHAR(64) DEFAULT NULL
 );
 
